#
# spec file for package perl-TheSchwartz
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name TheSchwartz
Name:           perl-TheSchwartz
Version:        1.180.0
Release:        1.1
# 1.18 -> normalize -> 1.180.0
%define cpan_version 1.18
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Reliable job queue
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/A/AK/AKIYM/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Class::Accessor::Fast)
BuildRequires:  perl(Data::ObjectDriver) >= 0.04
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Module::Build::Tiny) >= 0.035
Requires:       perl(Class::Accessor::Fast)
Requires:       perl(Data::ObjectDriver) >= 0.04
Provides:       perl(TheSchwartz) = %{version}
Provides:       perl(TheSchwartz::Error)
Provides:       perl(TheSchwartz::ExitStatus)
Provides:       perl(TheSchwartz::FuncMap)
Provides:       perl(TheSchwartz::Job)
Provides:       perl(TheSchwartz::JobHandle)
Provides:       perl(TheSchwartz::Worker)
%undefine       __perllib_provides
%{perl_requires}

%description
TheSchwartz is a reliable job queue system. Your application can put jobs
into the system, and your worker processes can pull jobs from the queue
atomically to perform. Failed jobs can be left in the queue to retry later.

_Abilities_ specify what jobs a worker process can perform. Abilities are
the names of 'TheSchwartz::Worker' sub-classes, as in the synopsis: the
'MyWorker' class name is used to specify that the worker script can perform
the job. When using the 'TheSchwartz' client's 'work' functions, the
class-ability duality is used to automatically dispatch to the proper class
to do the actual work.

TheSchwartz clients will also prefer to do jobs for unused abilities before
reusing a particular ability, to avoid exhausting the supply of one kind of
job while jobs of other types stack up.

Some jobs with high setup times can be performed more efficiently if a
group of related jobs are performed together. TheSchwartz offers a facility
to _coalesce_ jobs into groups, which a properly constructed worker can
find and perform at once. For example, if your worker were delivering
email, you might store the domain name from the recipient's address as the
coalescing value. The worker that grabs that job could then batch deliver
all the mail for that domain once it connects to that domain's mail server.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes doc README.md
%license LICENSE

%changelog
* Tue Dec 31 2024 Tina Müller <timueller+perl@suse.de>
- updated to 1.180.0 (1.18)
  see /usr/share/doc/packages/perl-TheSchwartz/Changes
  1.18 2024-12-31T00:55:27Z
  - docs: Fix link in documentation GH#14 (@mikkoi++)
  - docs: Fix typo and add a link to Data::ObjectDriver GH#13 (@mikkoi++)
* Fri Dec 31 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.17
  see /usr/share/doc/packages/perl-TheSchwartz/Changes
  1.17 2021-12-30T13:21:45Z
  - schwartzmon: 'Not an ARRAY reference' in DBSet::add for at least v5.16.3 GH#12 (@trwww++)
* Sat Jul 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.16
  see /usr/share/doc/packages/perl-TheSchwartz/Changes
  1.16 2021-07-16T07:49:43Z
  - Add ability to disable job randomization GH#9 (@jamadam++)
* Wed Jan 29 2020 <timueller+perl@suse.de>
- updated to 1.15
  see /usr/share/doc/packages/perl-TheSchwartz/Changes
  1.15 2020-01-28T06:19:54Z
  - Fix tests on win32 GH#4 (@charsbar++)
* Fri Oct 18 2019 <timueller+perl@suse.de>
- updated to 1.14
  see /usr/share/doc/packages/perl-TheSchwartz/Changes
  1.14 2019-10-17T17:51:40Z
  - Added missing prereq Class::Accessor::Fast as suggested by CPANTS. GH#1 (@manwar++)
* Thu Aug  8 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.13
  see /usr/share/doc/packages/perl-TheSchwartz/Changes
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.12
  see /usr/share/doc/packages/perl-TheSchwartz/CHANGES
  1.12 Mon Mar 30 2015
  - Fix replace_job hanging & postgresql issues. RT #65712
  - Add strict_remove_ability to prevent auto resetting of abilities.
  - Stricter job check. https://github.com/jfearn/TheSchwartz/pull/1
  - Add accessor methods for strict_remove_ability.
  - Add debug message to mark_database_as_dead. RT #102510
  1.11 Mon Nov 03 2014
  - Move from Make to Module::Build
  - Remove inc & autobuild
  - Add perltidyrc and run over all perl files.
  - Add perlcritic test & fix errors
  - Add Test::Spelling and fix all spelling errors in POD. RT #89165
  - Reorder jobs when prioritize is set. RT #99075
  - Fix wrong return precedence. RT #87222
  - Fix get_server_time for Oracle. # RT #58049
  - Support Data::ObjectDriver->get_dbh. RT #50022
  - Use sort by jobid on selects. RT #34843
  - Added floor methods to limit priortity job selection. RT #50842
  - Add batch_size methods to expose FIND_JOB_BATCH_SIZE. RT #72815
  - Add run_after param to decline. RT #60797
  - Add jobid param to list_jobs.
* Fri Apr 29 2011 coolo@opensuse.org
- updated to 1.10
  - Add $job->declined method for workers to be able to decline handling
    a job at this time.
  - Added $client->grab_and_work_on($handle) to securely work on a job
    you know the handle of. Yann Kerherve (yannk@cpan.org)
  - Fixed docs and tests (miyagawa, athomason, simonw)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Nov  6 2009 dmueller@suse.de
- Initial package (1.07)
